@@ -27,11 +27,6 @@ function openApplicationListSource(origin) {
     openApplicationList({ originFilter: origin, title: origin, allBackends: true })
 }
 
-function openUrlResources(uri) {
-    clearStack()
-    openApplicationList({ resourcesUrl: uri, title: uri, allBackends: true })
-}
-
 function openApplicationMime(mime) {
     clearStack()
     openApplicationList({ mimeTypeFilter: mime, title: i18n("Resources for '%1'", mime) })
