@@ -22,8 +22,8 @@
 #define UPDATEITEM_H
 
 // Qt includes
-#include <QtCore/QSet>
-#include <QtCore/QString>
+#include <QSet>
+#include <QString>
 #include "discovercommon_export.h"
 
 #include <QIcon>
@@ -36,13 +36,6 @@ public:
 
     ~UpdateItem();
 
-    enum Section {
-        ApplicationSection,
-        SystemSection
-    };
-
-    void setSection(const Section &section) { m_section = section; }
-    Section section() const { return m_section; }
     void setProgress(qreal progress);
     qreal progress() const;
 
@@ -51,7 +44,9 @@ public:
 
     AbstractResource *app() const;
     QString name() const;
-    QString version() const;
+    QString version() const; // Deprecated; use availableVersion() instead
+    QString availableVersion() const;
+    QString installedVersion() const;
     QVariant icon() const;
     qint64 size() const;
     Qt::CheckState checked() const;
@@ -65,7 +60,6 @@ private:
     const QIcon m_categoryIcon;
     qreal m_progress;
     QString m_changelog;
-    Section m_section;
 };
 
 #endif // UPDATEITEM_H
