@@ -63,9 +63,10 @@ QHash<int,QByteArray> UpdateModel::roleNames() const
         { ResourceProgressRole, "resourceProgress" },
         { ResourceRole, "resource" },
         { SizeRole, "size" },
-        { VersionRole, "version" },
         { SectionRole, "section" },
-        { ChangelogRole, "changelog" }
+        { ChangelogRole, "changelog" },
+        { InstalledVersionRole, "installedVersion" },
+        { AvailableVersionRole, "availableVersion" }
     } );
 }
 
@@ -124,8 +125,10 @@ QVariant UpdateModel::data(const QModelIndex &index, int role) const
         return item->icon();
     case Qt::CheckStateRole:
         return item->checked();
-    case VersionRole:
-        return item->version();
+    case InstalledVersionRole:
+        return item->installedVersion();
+    case AvailableVersionRole:
+        return item->availableVersion();
     case SizeRole:
         return KFormat().formatByteSize(item->size());
     case ResourceRole:
@@ -137,14 +140,16 @@ QVariant UpdateModel::data(const QModelIndex &index, int role) const
     case SectionRole: {
         static const QString appUpdatesSection = i18nc("@item:inlistbox", "Application Updates");
         static const QString systemUpdateSection = i18nc("@item:inlistbox", "System Updates");
-        switch(item->section()) {
-            case UpdateItem::ApplicationSection: return appUpdatesSection;
-            case UpdateItem::SystemSection: return systemUpdateSection;
+        static const QString addonsSection = i18nc("@item:inlistbox", "Addons");
+        switch(item->resource()->type()) {
+            case AbstractResource::Application: return appUpdatesSection;
+            case AbstractResource::Technical: return systemUpdateSection;
+            case AbstractResource::Addon: return addonsSection;
         }
-        return {};
-    } 
+        Q_UNREACHABLE();
+    }
     case SectionResourceProgressRole:
-        return (100-item->progress()) + (101 * item->section());
+        return (100-item->progress()) + (101 * item->resource()->type());
     default:
         break;
     }
@@ -194,13 +199,13 @@ bool UpdateModel::setData(const QModelIndex &idx, const QVariant &value, int rol
     return false;
 }
 
-void UpdateModel::fetchChangelog(int row)
+void UpdateModel::fetchUpdateDetails(int row)
 {
     UpdateItem *item = itemFromIndex(index(row, 0));
     Q_ASSERT(item);
     if (!item) return;
 
-    item->app()->fetchChangelog();
+    item->app()->fetchUpdateDetails();
 }
 
 void UpdateModel::integrateChangelog(const QString &changelog)
@@ -229,24 +234,29 @@ void UpdateModel::setResources(const QList<AbstractResource*>& resources)
     qDeleteAll(m_updateItems);
     m_updateItems.clear();
 
-    QVector<UpdateItem*> appItems, systemItems;
+    QVector<UpdateItem*> appItems, systemItems, addonItems;
     foreach(AbstractResource* res, resources) {
         connect(res, &AbstractResource::changelogFetched, this, &UpdateModel::integrateChangelog, Qt::UniqueConnection);
 
         UpdateItem *updateItem = new UpdateItem(res);
 
-        if(!res->isTechnical()) {
-            updateItem->setSection(UpdateItem::ApplicationSection);
-            appItems += updateItem;
-        } else {
-            updateItem->setSection(UpdateItem::SystemSection);
-            systemItems += updateItem;
+        switch(res->type()) {
+            case AbstractResource::Technical:
+                systemItems += updateItem;
+                break;
+            case AbstractResource::Application:
+                appItems += updateItem;
+                break;
+            case AbstractResource::Addon:
+                addonItems += updateItem;
+                break;
         }
     }
     const auto sortUpdateItems = [](UpdateItem *a, UpdateItem *b) { return a->name() < b->name(); };
     qSort(appItems.begin(), appItems.end(), sortUpdateItems);
     qSort(systemItems.begin(), systemItems.end(), sortUpdateItems);
-    m_updateItems = (QVector<UpdateItem*>() << appItems << systemItems);
+    qSort(addonItems.begin(), addonItems.end(), sortUpdateItems);
+    m_updateItems = (QVector<UpdateItem*>() << appItems << addonItems << systemItems);
     endResetModel();
 
     Q_EMIT hasUpdatesChanged(!resources.isEmpty());
@@ -325,9 +335,23 @@ void UpdateModel::resourceDataChanged(AbstractResource* res, const QVector<QByte
 
     const auto index = indexFromItem(item);
     if (properties.contains("state"))
-        Q_EMIT dataChanged(index, index, {SizeRole, VersionRole});
+        Q_EMIT dataChanged(index, index, {SizeRole, AvailableVersionRole});
     else if (properties.contains("size")) {
         Q_EMIT dataChanged(index, index, {SizeRole});
         m_updateSizeTimer->start();
     }
 }
+
+void UpdateModel::checkAll()
+{
+    for(int i=0, c=rowCount(); i<c; ++i)
+        if(index(i,0).data(Qt::CheckStateRole) != Qt::Checked)
+            setData(index(i,0), Qt::Checked, Qt::CheckStateRole);
+}
+
+void UpdateModel::uncheckAll()
+{
+    for(int i=0, c=rowCount(); i<c; ++i)
+        if(index(i,0).data(Qt::CheckStateRole) != Qt::Unchecked)
+            setData(index(i,0), Qt::Unchecked, Qt::CheckStateRole);
+}
