@@ -52,7 +52,6 @@ ResourcesProxyModel::ResourcesProxyModel(QObject *parent)
         { DisplayOriginRole, "displayOrigin" },
         { CanUpgrade, "canUpgrade" },
         { PackageNameRole, "packageName" },
-        { IsTechnicalRole, "isTechnical" },
         { CategoryRole, "category" },
         { CategoryDisplayRole, "categoryDisplay" },
         { SectionRole, "section" },
@@ -582,6 +581,20 @@ AbstractResource * ResourcesProxyModel::resourceAt(int row) const
     return m_displayedResources[row];
 }
 
+bool ResourcesProxyModel::canFetchMore(const QModelIndex& parent) const
+{
+    Q_ASSERT(!parent.isValid());
+    return m_currentStream;
+}
+
+void ResourcesProxyModel::fetchMore(const QModelIndex& parent)
+{
+    Q_ASSERT(!parent.isValid());
+    if (!m_currentStream)
+        return;
+    m_currentStream->fetchMore();
+}
+
 bool ResourcesProxyModel::sortByRelevancy() const
 {
     return m_sortByRelevancy;
