@@ -137,6 +137,7 @@ void ResourcesUpdatesModel::init()
             connect(updater, &AbstractBackendUpdater::downloadSpeedChanged, this, &ResourcesUpdatesModel::downloadSpeedChanged);
             connect(updater, &AbstractBackendUpdater::resourceProgressed, this, &ResourcesUpdatesModel::resourceProgressed);
             connect(updater, &AbstractBackendUpdater::passiveMessage, this, &ResourcesUpdatesModel::passiveMessage);
+            connect(updater, &AbstractBackendUpdater::needsRebootChanged, this, &ResourcesUpdatesModel::needsRebootChanged);
             connect(updater, &AbstractBackendUpdater::destroyed, this, &ResourcesUpdatesModel::updaterDestroyed);
             m_updaters += updater;
 
@@ -196,7 +197,7 @@ void ResourcesUpdatesModel::updateAll()
         }
 
         QMetaObject::invokeMethod(this, [this](){
-            m_transaction->setStatus(Transaction::QueuedStatus);
+            m_transaction->setStatus(Transaction::CommittingStatus);
             m_transaction->slotProgressingChanged();
         }, Qt::QueuedConnection);
 
@@ -281,4 +282,13 @@ Transaction* ResourcesUpdatesModel::transaction() const
     return m_transaction.data();
 }
 
+bool ResourcesUpdatesModel::needsReboot() const
+{
+    for(auto upd: m_updaters) {
+        if (upd->needsReboot())
+            return true;
+    }
+    return false;
+}
+
 #include "ResourcesUpdatesModel.moc"
